@@ -118,8 +118,8 @@ def _prerelease():
 
             print(f'      #{pull.number}: {pull.title} ({pull.head.ref})')
 
-            if not pull.mergeable:
-                print("\njavelin: pull request can't be merged")
+            if not pull.mergeable or pull.mergeable_state != 'clean':
+                print(f"\njavelin: pull request can't be merged ({pull.mergeable_state})")
                 sys.exit(2)
 
         print(f'\n  2. Create a new GitHub Release with version {prerelease_version}')
@@ -129,14 +129,15 @@ def _prerelease():
         print('  Only "yes" will be accepted.\n')
 
         if input('\033[1mEnter a value:\033[0m ') == 'yes':
-            github.run_prerelease(repo, prerelease_version, pulls)
+            github_succeeded = github.run_prerelease(repo, prerelease_version, pulls)
 
-            succeeded = aws.start_pipeline_execution_and_wait(project_name, 'staging')
+            if github_succeeded:
+                aws_succeeded = aws.start_pipeline_execution_and_wait(project_name, 'staging')
 
-            if succeeded:
-                slack.notify_prerelease(project_name, repo, prerelease_version)
-            else:
-                slack.notify_prerelease_error(project_name, repo, prerelease_version, pulls)
+                if aws_succeeded:
+                    slack.notify_prerelease(project_name, repo, prerelease_version)
+                else:
+                    slack.notify_prerelease_error(project_name, repo, prerelease_version, pulls)
     except KeyboardInterrupt:
         print('\n\nBye-bye')
 
