@@ -30,12 +30,18 @@ def get_prerelease_version(repo, bump_level):
     return bump_version('0.0.0', bump_level)
 
 def run_prerelease(repo, version, pulls):
-    _merge_pull_requests(repo, pulls)
+    try:
+        _merge_pull_requests(repo, pulls)
 
-    if prerelease := get_latest_prerelease(repo):
-        update_prerelease(prerelease, repo, version)
-    else:
-        create_prerelease(repo, version)
+        if prerelease := get_latest_prerelease(repo):
+            update_prerelease(prerelease, repo, version)
+        else:
+            create_prerelease(repo, version)
+
+        return True
+    except GithubException as err:
+        print(f"\njavelin: {err.data['message']}")
+        return False
 
 def run_release(repo):
     if prerelease := get_latest_prerelease(repo):
@@ -95,14 +101,11 @@ def _client():
     return Github(os.environ.get('GITHUB_ACCESS_TOKEN'))
 
 def _merge_pull_requests(repo, pulls):
-    try:
-        for pull in pulls:
-            print(f'Merging pull request #{pull.number}')
+    for pull in pulls:
+        print(f'Merging pull request #{pull.number}')
 
-            repo.merge(repo.default_branch, pull.head.sha, f'{pull.title} #{pull.number}')
-            repo.get_git_ref(f"heads/{pull.head.ref}").delete()
-    except GithubException as err:
-        print(f"\njavelin: {err.data['message']}")
+        repo.merge(repo.default_branch, pull.head.sha, f'{pull.title} #{pull.number}')
+        repo.get_git_ref(f"heads/{pull.head.ref}").delete()
 
 def create_prerelease(repo, version):
     print(f'Creating pre-release {version}')
@@ -159,7 +162,11 @@ def build_release_message(repo, version):
 
 def commits_between_prerelease_and_latest_release(repo, prerelease_version):
     try:
-        since = repo.get_latest_release().published_at
+        tag_name = repo.get_latest_release().tag_name
+        tag_commit_sha = repo.get_commit(tag_name).sha
+        tag_commit = repo.get_git_commit(tag_commit_sha)
+
+        since = tag_commit.author.date + datetime.timedelta(seconds=1)
     except UnknownObjectException:
         since = datetime.datetime.now() - datetime.timedelta(days=7)
 
